@@ -34,20 +34,15 @@
 #include <X11/Xlib.h>
 #include <gdk/gdkx.h>
 #include <gio/gio.h>
+#include <unistd.h>
+#include <libslab/slab.h>
 
-#include "tile.h"
-#include "application-tile.h"
-#include "document-tile.h"
-#include "directory-tile.h"
-#include "system-tile.h"
 #include "hard-drive-status-tile.h"
 #include "network-status-tile.h"
 
 #include "tile-table.h"
 
 #include "tomboykeybinder.h"
-#include "libslab-utils.h"
-#include "double-click-detector.h"
 
 #define ROOT_GCONF_DIR             "/desktop/gnome/applications/main-menu"
 #define CURRENT_PAGE_GCONF_KEY     ROOT_GCONF_DIR "/file-area/file_class"
@@ -441,7 +436,7 @@ main_menu_ui_finalize (GObject *g_obj)
 		g_object_unref (G_OBJECT (g_object_get_data (
 			G_OBJECT (priv->panel_buttons [i]), "double-click-detector")));
 
-		gtk_widget_unref (GTK_WIDGET (priv->panel_buttons [i]));
+		g_object_unref (priv->panel_buttons [i]);
 	}
 
 	libslab_gconf_notify_remove (priv->search_cmd_gconf_mntr_id);
@@ -505,7 +500,7 @@ create_panel_button (MainMenuUI *this)
 
 		button_parent = gtk_widget_get_parent (GTK_WIDGET (priv->panel_buttons [i]));
 
-		gtk_widget_ref (GTK_WIDGET (priv->panel_buttons [i]));
+		g_object_ref (priv->panel_buttons [i]);
 		gtk_container_remove (
 			GTK_CONTAINER (button_parent), GTK_WIDGET (priv->panel_buttons [i]));
 
@@ -2428,7 +2423,7 @@ panel_applet_change_background_cb (PanelApplet *applet, PanelAppletBackgroundTyp
 	gtk_widget_set_style (GTK_WIDGET (priv->panel_applet), NULL);
 	rc_style = gtk_rc_style_new ();
 	gtk_widget_modify_style (GTK_WIDGET (priv->panel_applet), rc_style);
-	gtk_rc_style_unref (rc_style);
+	g_object_unref (rc_style);
 
 	switch (type) {
 		case PANEL_NO_BACKGROUND:
